from brain_games.cli import greet_user
import prompt

MAX_LIMIT = 3


def play(game):
    user_name = greet_user()
    print(game.GAME_DESCRIPTION)
    for _ in range(MAX_LIMIT):
        question, right_answer = game.get_question_answer()
        print(f'Question: {question}')
        user_answer = prompt.string('Your answer: ')
        if user_answer == right_answer:
            print('Correct!')
        else:
            print('{} is wrong answer ;(. Correct answer was {}'.format(
                user_answer, right_answer
            ))
            print(f"Let's try again, {user_name}!")
            break
    else:
        print(f'Congratulations, {user_name}!')



import random

GAME_DESCRIPTION = 'What number is missing in the progression?'
LENGTH = 10


def get_question_answer():
    start = random.randint(0, 20)
    step = random.randint(-5, 5)
    progression = [str(start + step * i) for i in range(1, LENGTH + 1)]
    missing_index = random.randint(0, LENGTH - 1)
    right_answer = progression[missing_index]
    progression[missing_index] = '..'
    question = ' '.join(progression)
    return question, right_answer



import random

GAME_DESCRIPTION = '''
Answer "yes" if given number is prime. Otherwise answer "no".'''


def get_question_answer():
    question = random.randrange(100)
    right_answer = 'yes' if is_prime(question) else 'no'
    return question, right_answer


def is_prime(number):
    if number < 2:
        return False
    for i in range(2, number // 2):
        if number % i == 0:
            return False
    return True



from math import gcd
import random

GAME_DESCRIPTION = 'Find the greatest common divisor of given numbers.'


def get_question_answer():
    x1 = random.randint(0, 50)
    x2 = random.randint(0, 50)
    question = '{} {}'.format(x1, x2)
    right_answer = str(gcd(x1, x2))
    return question, right_answer



import random

GAME_DESCRIPTION = 'Answer "yes" if the number is even, otherwise answer "no".'


def get_question_answer():
    question = random.randint(1, 100)
    if question % 2 == 0:
        right_answer = 'yes'
    else:
        right_answer = 'no'
    return question, right_answer



import random
from operator import add, sub, mul

OPERATIONS = [
    ('+', add),
    ('-', sub),
    ('*', mul)
]

GAME_DESCRIPTION = 'What is the result of the expression?'


def get_question_answer():
    x1 = random.randint(0, 25)
    x2 = random.randint(0, 25)
    sign, operation = random.choice(OPERATIONS)
    question = '{} {} {}'.format(x1, sign, x2)
    right_answer = str(operation(x1, x2))
    return question, right_answer
